@@ -1,5 +1,5 @@
 import json
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Optional, Union
 from uuid import UUID
 
 import requests
@@ -7,12 +7,16 @@ import requests
 from odp.client.exc import OdpValidationError
 from odp.client.http_client import OdpHttpClient
 from odp.dto.catalogv2.catalog import (
+    Contributor,
+    CreateCustomContributorRequest,
+    CreateCustomLicenseRequest,
     CreateDataCollectionRequest,
     CreateDatasetRequest,
     CreateStaticPropertyRequest,
     DataCollection,
     Dataset,
     DatasetProperty,
+    LicenseEntity,
     UpdateDataCollectionRequest,
     UpdateDatasetRequest,
     UpdateStaticPropertyMetadataRequest,
@@ -514,7 +518,9 @@ class CatalogClient(BaseModel):
         except requests.HTTPError as e:
             raise requests.HTTPError(f"HTTP Error - {res.status_code}: {res.text}") from e
 
-        return [DatasetProperty(**item) for item in res.json()]
+        if res.json():
+            return [DatasetProperty(**item) for item in res.json()]
+        return []
 
     def get_property_by_name(
         self,
@@ -806,3 +812,219 @@ class CatalogClient(BaseModel):
             grouped_results.append(grouped_result)
 
         return grouped_results
+
+    def get_all_contributors(
+        self,
+    ) -> List[Contributor]:
+        """Retrieve all contributors.
+
+        Returns:
+            A list of Contributor objects
+
+        Raises:
+            requests.HTTPError: For unexpected HTTP errors
+        """
+        url = f"{self.catalog_base_url}/contributors"
+        res = self.http_client.get(url)
+        try:
+            res.raise_for_status()
+        except requests.HTTPError as e:
+            raise requests.HTTPError(f"HTTP Error - {res.status_code}: {res.text}") from e
+
+        if res.json():
+            return [Contributor(**item) for item in res.json().get("items", [])]
+        return []
+
+    def get_contributor(
+        self,
+        contributor_id: UUID,
+    ) -> Optional[Contributor]:
+        """Retrieve a contributor.
+
+        Args:
+            contributor_id: The ID of the contributor
+
+        Returns:
+            A Contributor object
+
+        Raises:
+            requests.HTTPError: For unexpected HTTP errors
+        """
+        url = f"{self.catalog_base_url}/contributors/{str(contributor_id)}"
+        res = self.http_client.get(url)
+        try:
+            res.raise_for_status()
+        except requests.HTTPError as e:
+            raise requests.HTTPError(f"HTTP Error - {res.status_code}: {res.text}") from e
+
+        if res.json():
+            return Contributor(**res.json())
+        return None
+
+    def add_custom_contributor(
+        self,
+        request: CreateCustomContributorRequest,
+    ) -> Contributor:
+        """Create a custom contributor.
+
+        Args:
+            request: The property creation request
+
+        Returns:
+            The created custom contributor
+
+        Raises:
+            OdpValidationError: If the request is invalid
+            requests.HTTPError: For other unexpected HTTP errors
+        """
+        url = f"{self.catalog_base_url}/custom-contributors"
+        res = self.http_client.post(url, content=request)
+        try:
+            res.raise_for_status()
+        except requests.HTTPError as e:
+            if res.status_code == 400:
+                raise OdpValidationError("Invalid input", res.text) from e
+            if res.status_code == 500:
+                raise requests.HTTPError(f"Internal server error ({res.status_code}): {res.text}") from e
+            raise requests.HTTPError(f"HTTP Error - {res.status_code}: {res.text}")
+
+        return Contributor(**res.json())
+
+    def add_provider_to_dataset(
+        self,
+        dataset_id: UUID,
+        contributor_id: UUID,
+    ) -> Contributor:
+        """Add a provider to a dataset.
+
+        Args:
+            dataset_id: The ID of the dataset
+            contributor_id: The ID of the contributor
+
+        Returns:
+            The updated contributor
+
+        Raises:
+            OdpValidationError: If the request is invalid
+            requests.HTTPError: For other unexpected HTTP errors
+        """
+        url = f"{self.catalog_base_url}/datasets/{dataset_id}/provider"
+        res = self.http_client.post(url, content={"id": str(contributor_id)})
+        try:
+            res.raise_for_status()
+        except requests.HTTPError as e:
+            if res.status_code == 400:
+                raise OdpValidationError("Invalid input", res.text) from e
+            if res.status_code == 500:
+                raise requests.HTTPError(f"Internal server error ({res.status_code}): {res.text}") from e
+            raise requests.HTTPError(f"HTTP Error - {res.status_code}: {res.text}")
+
+        return Contributor(**res.json())
+
+    def add_custom_license(
+        self,
+        request: CreateCustomLicenseRequest,
+    ) -> LicenseEntity:
+        """Create a custom license.
+
+        Args:
+            request: The property creation request
+
+        Returns:
+            The created custom license
+
+        Raises:
+            OdpValidationError: If the request is invalid
+            requests.HTTPError: For other unexpected HTTP errors
+        """
+        url = f"{self.catalog_base_url}/custom-licenses"
+        res = self.http_client.post(url, content=request)
+        try:
+            res.raise_for_status()
+        except requests.HTTPError as e:
+            if res.status_code == 400:
+                raise OdpValidationError("Invalid input", res.text) from e
+            if res.status_code == 500:
+                raise requests.HTTPError(f"Internal server error ({res.status_code}): {res.text}") from e
+            raise requests.HTTPError(f"HTTP Error - {res.status_code}: {res.text}")
+
+        return LicenseEntity(**res.json())
+
+    def get_all_licenses(
+        self,
+    ) -> List[LicenseEntity]:
+        """Retrieve all licenses.
+
+        Returns:
+            A list of LicenseEntity objects
+
+        Raises:
+            requests.HTTPError: For unexpected HTTP errors
+        """
+        url = f"{self.catalog_base_url}/licenses"
+        res = self.http_client.get(url)
+        try:
+            res.raise_for_status()
+        except requests.HTTPError as e:
+            raise requests.HTTPError(f"HTTP Error - {res.status_code}: {res.text}") from e
+
+        if res.json():
+            return [LicenseEntity(**item) for item in res.json().get("items", [])]
+        return []
+
+    def get_license(
+        self,
+        license_id: UUID,
+    ) -> Optional[LicenseEntity]:
+        """Retrieve a license.
+
+        Args:
+            license_id: The ID of the license
+
+        Returns:
+            A LicenseEntity object
+
+        Raises:
+            requests.HTTPError: For unexpected HTTP errors
+        """
+        url = f"{self.catalog_base_url}/licenses/{str(license_id)}"
+        res = self.http_client.get(url)
+        try:
+            res.raise_for_status()
+        except requests.HTTPError as e:
+            raise requests.HTTPError(f"HTTP Error - {res.status_code}: {res.text}") from e
+
+        if res.json():
+            return LicenseEntity(**res.json())
+        return None
+
+    def add_license_to_dataset(
+        self,
+        dataset_id: UUID,
+        license_id: UUID,
+    ) -> LicenseEntity:
+        """Add a license to a dataset.
+
+        Args:
+            dataset_id: The ID of the dataset
+            license_id: The ID of the license
+
+        Returns:
+            The updated license
+
+        Raises:
+            OdpValidationError: If the request is invalid
+            requests.HTTPError: For other unexpected HTTP errors
+        """
+        url = f"{self.catalog_base_url}/datasets/{dataset_id}/license"
+        res = self.http_client.post(url, content={"id": str(license_id)})
+        try:
+            res.raise_for_status()
+        except requests.HTTPError as e:
+            if res.status_code == 400:
+                raise OdpValidationError("Invalid input", res.text) from e
+            if res.status_code == 500:
+                raise requests.HTTPError(f"Internal server error ({res.status_code}): {res.text}") from e
+            raise requests.HTTPError(f"HTTP Error - {res.status_code}: {res.text}")
+
+        return LicenseEntity(**res.json())
