@@ -114,7 +114,7 @@ class Client:
             s.mount("http://", adapter)
             s.mount("https://", adapter)
             res = s.send(preq, stream=True)
-        logging.info("response: %s in %.2fs", res.status_code, res.elapsed.total_seconds())
+        logging.info("response: %s in %.2fs from %s", res.status_code, res.elapsed.total_seconds(), res.url)
         return res
 
     def dataset(self, id: str) -> "Dataset":
